Module: Google::Cloud::Scheduler
- Defined in:
- lib/google/cloud/scheduler.rb,
lib/google/cloud/scheduler/version.rb
Constant Summary collapse
- VERSION =
"3.2.0"
Class Method Summary collapse
-
.cloud_scheduler(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for CloudScheduler.
-
.cloud_scheduler_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the CloudScheduler service is supported by the current client.
-
.configure {|::Google::Cloud.configure.scheduler| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-scheduler library.
Class Method Details
.cloud_scheduler(version: :v1, transport: :grpc, &block) ⇒ ::Object
Create a new client object for CloudScheduler.
By default, this returns an instance of
Google::Cloud::Scheduler::V1::CloudScheduler::Client
for a gRPC client for version V1 of the API.
However, you can specify a different API version by passing it in the
version parameter. If the CloudScheduler service is
supported by that API version, and the corresponding gem is available, the
appropriate versioned client will be returned.
You can also specify a different transport by passing :rest or :grpc in
the transport parameter.
Raises an exception if the currently installed versioned client gem for the given API version does not support the given transport of the CloudScheduler service. You can determine whether the method will succeed by calling cloud_scheduler_available?.
About CloudScheduler
The Cloud Scheduler API allows external entities to reliably schedule asynchronous jobs.
76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/google/cloud/scheduler.rb', line 76 def self.cloud_scheduler version: :v1, transport: :grpc, &block require "google/cloud/scheduler/#{version.to_s.downcase}" package_name = Google::Cloud::Scheduler .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first service_module = Google::Cloud::Scheduler.const_get(package_name).const_get(:CloudScheduler) service_module = service_module.const_get(:Rest) if transport == :rest service_module.const_get(:Client).new(&block) end |
.cloud_scheduler_available?(version: :v1, transport: :grpc) ⇒ boolean
Determines whether the CloudScheduler service is supported by the current client. If true, you can retrieve a client object by calling cloud_scheduler. If false, that method will raise an exception. This could happen if the given API version does not exist or does not support the CloudScheduler service, or if the versioned client gem needs an update to support the CloudScheduler service.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/google/cloud/scheduler.rb', line 100 def self.cloud_scheduler_available? version: :v1, transport: :grpc require "google/cloud/scheduler/#{version.to_s.downcase}" package_name = Google::Cloud::Scheduler .constants .select { |sym| sym.to_s.downcase == version.to_s.downcase.tr("_", "") } .first return false unless package_name service_module = Google::Cloud::Scheduler.const_get package_name return false unless service_module.const_defined? :CloudScheduler service_module = service_module.const_get :CloudScheduler if transport == :rest return false unless service_module.const_defined? :Rest service_module = service_module.const_get :Rest end service_module.const_defined? :Client rescue ::LoadError false end |
.configure {|::Google::Cloud.configure.scheduler| ... } ⇒ ::Google::Cloud::Config
Configure the google-cloud-scheduler library.
The following configuration parameters are supported:
credentials(type:String, Hash, Google::Auth::Credentials) - The path to the keyfile as a String, the contents of the keyfile as a Hash, or a Google::Auth::Credentials object.lib_name(type:String) - The library name as recorded in instrumentation and logging.lib_version(type:String) - The library version as recorded in instrumentation and logging.interceptors(type:Array<GRPC::ClientInterceptor>) - An array of interceptors that are run before calls are executed.timeout(type:Numeric) - Default timeout in seconds.metadata(type:Hash{Symbol=>String}) - Additional headers to be sent with the call.retry_policy(type:Hash) - The retry policy. The value is a hash with the following keys::initial_delay(type:Numeric) - The initial delay in seconds.:max_delay(type:Numeric) - The max delay in seconds.:multiplier(type:Numeric) - The incremental backoff multiplier.:jitter(type:Numeric) - The jitter in seconds. Default: 1.0.:retry_codes(type:Array<String>) - The error codes that should trigger a retry.
148 149 150 151 152 |
# File 'lib/google/cloud/scheduler.rb', line 148 def self.configure yield ::Google::Cloud.configure.scheduler if block_given? ::Google::Cloud.configure.scheduler end |